@@ -1,5 +1,12 @@
-from firstimpression.constants import TEMP_FOLDER, APIS
+from firstimpression.constants import TEMP_FOLDER
+from firstimpression.constants import APIS
 from firstimpression.file import download_install_media
+from firstimpression.file import update_directories_api
+from firstimpression.file import check_too_old
+from firstimpression.file import write_root_to_xml_files
+from firstimpression.xml import get_xml
+from firstimpression.scala import log
+from logging import _nameToLevel
 import xml.etree.ElementTree as ET
 import os
 
@@ -28,6 +35,29 @@ TAGS = {
     'image': 'NP:Media/NP:Image'
 }
 
+def run_api():
+    update_directories_api(NAME)
+    
+    if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
+        root = get_xml(URL)
+        new_root = ET.Element("root")
+        counter = 0
+
+        download_install_logo()
+
+        for alert in get_alerts(root):
+            counter += 1
+            new_root.append(parse_alert(alert))
+        
+        ET.SubElement(new_root, "alerts").text = str(counter)
+
+        write_root_to_xml_files(new_root, XML_TEMP_PATH, NAME)
+        
+    else:
+        log(_nameToLevel['INFO'],'File not old enough to update')
+
+
+
 def download_install_logo():
     download_install_media(URL_LOGO, TEMP_FOLDER, NAME)
 
