@@ -1,7 +1,16 @@
 import datetime
 import time
+import locale
 from firstimpression.xml import get_text_from_element
+from firstimpression.constants import ENGLISH_INDEX, DUTCH_INDEX
 
+def change_language(language_index):
+    if language_index == ENGLISH_INDEX:
+        language = 'en_US'
+    elif language_index == DUTCH_INDEX:
+        language = 'nl_NL'
+    
+    locale.setlocale(locale.LC_TIME, language)
 
 def get_datetime_object_from_element(element, name, format):
     """ Gets the datetime object of an element (xml) based on name and format
@@ -74,38 +83,4 @@ def parse_string_time_to_minutes(element):
     return minutes
 
 def parse_string_to_string(element, format, new_format):
-    return parse_date_to_string(parse_string_to_date(element, format), new_format)
-
-def get_month_text(month_number, month_index, language_index=1):
-    return{
-        1: [['Jan', 'January'], ['jan', 'januari']],
-        2: [['Feb', 'February'], ['feb', 'februari']],
-        3: [['Mar', 'March'], ['maart', 'maart']],
-        4: [['Apr', 'April'], ['apr', 'april']],
-        5: [['May', 'May'], ['mei', 'mei']],
-        6: [['June', 'June'], ['juni', 'juni']],
-        7: [['July', 'July'], ['juli', 'juli']],
-        8: [['Aug', 'August'], ['aug', 'augustus']],
-        9: [['Sept', 'September'], ['sept', 'september']],
-        10: [['Oct', 'October'], ['okt', 'oktober']],
-        11: [['Nov', 'November'], ['nov', 'november']],
-        12: [['Dec', 'December'], ['dec', 'december']]
-    }[month_number][language_index][month_index]
-
-
-def parse_date_to_string_full_day_month(date_object, month_type):
-    day = str(date_object.day)
-    month = get_month_text(date_object.month, month_type, 1)
-    return ' '.join([day, month, parse_date_to_string(date_object, '%Y %H:%M')])
-
-
-def parse_date_to_string_full_month_day(date_object, month_type):
-    day = str(date_object.day)
-    month = get_month_text(date_object.month, month_type, 0)
-    return ' '.join([month, day, parse_date_to_string(date_object, '%Y %H:%M')])
-
-def parse_date_to_string_full(date_object, month_type, language_index):
-    if language_index == 1:
-        return parse_date_to_string_full_day_month(date_object, month_type)
-    else:
-        return parse_date_to_string_full_month_day(date_object, month_type)
+    return parse_date_to_string(parse_string_to_date(element, format), new_format)
\ No newline at end of file
